Crate kcr_policy_networking_k8s_io

Crate kcr_policy_networking_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the policy.networking.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

policy.networking.k8s.io/v1alpha1

  • AdminNetworkPolicy
  • BaselineAdminNetworkPolicy

policy.networking.k8s.io/v1alpha2

  • ClusterNetworkPolicy

Modules

v1alpha1
v1alpha2