This crate contains kube-rs compatible bindings for Kubernetes custom resources for the policy.networking.k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
policy.networking.k8s.io/v1alpha1
AdminNetworkPolicyBaselineAdminNetworkPolicy
policy.networking.k8s.io/v1alpha2
ClusterNetworkPolicy